summaryrefslogtreecommitdiffstats
path: root/k9author/import.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'k9author/import.cpp')
-rw-r--r--k9author/import.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/k9author/import.cpp b/k9author/import.cpp
index 48593bd..69ebdbc 100644
--- a/k9author/import.cpp
+++ b/k9author/import.cpp
@@ -24,11 +24,11 @@
#include "kselect.h"
/*
* Constructs a import as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-import::import( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+import::import( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "import" );
@@ -24,11 +24,11 @@
#include "kselect.h"
/*
- * Constructs a import as a child of 'tqparent', with the
+ * Constructs a import as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/